pilot.impl.pilot_manager_decentral

Package pilot :: Package impl :: Module pilot_manager_decentral |

# Module pilot_manager_decentral

source code

ComputeDataServiceDecentral Module: A decentral implementation of a ComputeDataService (see ComputeDataServiceDecentral).

A Meta-Scheduling service for pilots (both PilotCompute and PilotData)

Classes
| ComputeDataServiceDecentral ComputeDataServiceDecentral.

Variables
| __package__ = ``'``pilot.impl``'``